@@ -2,10 +2,10 @@ use strict;
 use warnings;
 package A1z::HTML5::Template;
 
-# ABSTRACT: turns baubles into trinkets
+# ABSTRACT: Fast/easy HTML5 apps/pages in Perl
 
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 
 
@@ -36,9 +36,8 @@ sub math1
 	if ($num2 eq '') { $num2 = '4'; }
 	
 	my $out;
-	#$out .= "Repeat this line 4 times\n"  x 4 . "\n";
 	
-	my $m = $num1 * $num2;		# To avoid error: #Argument "Addition 8 + 4 = 8" isn't numeric in addition <+> at Template.PM line 70# do the math in a new var
+	my $m = $num1 * $num2;
 	my $a  = $num1 + $num2;
 	my $s  = $num1 - $num2;
 	my $s1 = $num2 - $num1;
@@ -198,10 +197,10 @@ sub body_js_css
 	my $out; 
 	
 	$out .= qq{<!--jquery-->
-<script src="/jquery/jquery-1.11.1.min.js"></script>
+<script src="https://code.jquery.com/jquery-1.12.4.min.js"></script>
 <!--bootstrap/jQueryUI-->
-<script src="/jquery/bootstrap/js/bootstrap.min.js"></script>
-<script src="/jquery/ui/1.11.2.lightness/jquery-ui.min.js"></script>
+<script src="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.0/js/bootstrap.min.js"></script>
+<script src="https://code.jquery.com/ui/1.11.4/jquery-ui.min.js"></script>
 
 <!-- IE10 viewport hack for Surface/desktop Windows 8 bug -->
 <script type="text/javascript" src="/jquery/bootstrap/fixed-top/ie10-viewport-bug-workaround.js"></script>
@@ -298,11 +297,11 @@ sub end_html
 	
 	my $out; 
 		
-	$out .= qq~</html>\n\n~;
+	$out .= qq{</html>\n\n};
 	
 	if ($ARGV and $ARGV > 0 or scalar(@keys) > 0) 
 	{
-		return qq~@_~;
+		return qq{@_};
 	}
 	else 
 	{	
@@ -323,24 +322,24 @@ sub head_title
 	
 	my $out; 
 	
-	$out .= qq~~; 
+	$out .= qq{}; 
 	
 	if ($ARGV and $ARGV > 0 or scalar(@keys) > 0) 
 	{
 		
 		if ($key) 
 		{
-			return qq~<title>@_</title>\n~; 
+			return qq{<title>@_</title>\n}; 
 		}
 		else 
 		{
-			return qq~<title>Template</title>\n~; 
+			return qq{<title>Template</title>\n}; 
 		}
 		
 	}
 	else 
 	{
-		return qq~<title>Package Html5</title>\n~; 	# this works but does not ask the user
+		return qq{<title>Package Html5</title>\n}; 	# this works but does not ask the user
 	}
 	
 } 
@@ -360,12 +359,12 @@ sub head_meta
 	
 	my $out; 
 	
-	$out .= qq~<meta charset="utf-8">
+	$out .= qq{<meta charset="utf-8">
 <meta lang="en">
 <meta http-equiv="X-UA-Compatible" content="IE=edge"> 
 <meta name="HandheldFriendly" content="true"> 
 <meta name="viewport" content="width=device-width, initial-scale=1"> 
-~; 
+}; 
 	
 	if ($args) 
 	{
@@ -380,22 +379,22 @@ sub head_meta
 				
 				my ( $meta_name, $meta_cont) = split(/---/, $_, 2);
 				
-				$return .= qq~<meta name="$meta_name" content="$meta_cont">\n~; 
+				$return .= qq{<meta name="$meta_name" content="$meta_cont">\n}; 
 			}
 			
-			return qq~$return<!--360-->~; 
+			return qq{$return<!--360-->}; 
 		}
 		else 
 		{
-			$out .= qq~<meta name="description" content="HTML5 by Business Impact Solutions - bislinks.com"/><!--364-->~; 
+			$out .= qq{<meta name="description" content="HTML5 by Business Impact Solutions - bislinks.com"/><!--364-->}; 
 			# add default meta if user has not called one of his own
-			return qq~$out~; 
+			return qq{$out}; 
 		}
 		
 	}
 	else 
 	{
-		return qq~$out~; 	# this works but does not ask the user
+		return qq{$out}; 	# this works but does not ask the user
 	}
 	
 } 
@@ -409,7 +408,7 @@ sub body_topnavbar
 	my %in;
 	
 	%in = (
-		file => "/A1z/Html5/Template/tob-nav-bar.js",
+		file => "https://secure.bislinks.com/js/utils/top-nav-bar.js",
 		name => "Menu",
 		@_,
 	);
@@ -424,7 +423,7 @@ sub body_topnavbar
 <!-- top nav bar end--> 
 }; 
 	
-	return qq~$out\n~; 	# this works but does not ask the user
+	return qq{$out\n}; 	# this works but does not ask the user
 	
 } 
 # end body top nav bar
@@ -442,12 +441,11 @@ sub head_js_css
 	
 	my $out; 
 	
-	$out .= qq~<!-- Bootstrap/jqueryUI -->
+	$out .= qq{<!-- Bootstrap/jqueryUI -->
 
-<link href="/jquery/bootstrap/css/bootstrap.min.css" rel="stylesheet" type="text/css">
-<link href="/jquery/bootstrap/fixed-top/navbar-fixed-top.css" rel="stylesheet">
-<link href="/jquery/ui/themes/smoothness/jquery-ui.min.css" rel="stylesheet">
-<link href="/jquery/ui/themes/smoothness/theme.css" rel="stylesheet">
+<link href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.0/css/bootstrap.min.css" rel="stylesheet" type="text/css">
+<link href="https://secure.bislinks.com/jquery/bootstrap/fixed-top/navbar-fixed-top.css" rel="stylesheet">
+<link href="https://code.jquery.com/ui/1.12.1/themes/smoothness/jquery-ui.css" rel="stylesheet">
 
 <!-- HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries -->
 <!--[if lt IE 9]>
@@ -455,7 +453,7 @@ sub head_js_css
 <script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
 <![endif]-->
 
-~; 
+}; 
 	
 	if ($args) 
 	{
@@ -469,30 +467,30 @@ sub head_js_css
 				chomp;
 				if ($_ =~ /.js$/)
 				{
-					$return .= qq~<!--442--> \n<script type="text/javascript" src="$_"></script> \n~; 
+					$return .= qq{<!--442--> \n<script type="text/javascript" src="$_"></script> \n}; 
 				}
 				elsif ($_ =~ /.css$/)
 				{
-					$return .= qq~<!--446--> \n<link href="$_" rel="stylesheet" style="text/css"> \n~; 
+					$return .= qq{<!--446--> \n<link href="$_" rel="stylesheet" style="text/css"> \n}; 
 				}
 				else 
 				{
 					# do nothing
-					return qq~@keys<!--469-->\n~; 
+					return qq{@keys<!--469-->\n}; 
 				}
 			}
 			
-			return qq~$return<!--473 jQ-->\n~; 
+			return qq{$return<!--473 jQ-->\n}; 
 		}
 		else 
 		{
-			return qq~$out\n~; 
+			return qq{$out\n}; 
 		}
 		
 	}
 	else 
 	{
-		return qq~$out\n~; 	# this works but does not ask the user
+		return qq{$out\n}; 	# this works but does not ask the user
 	}
 	
 } 
@@ -510,24 +508,24 @@ sub end_head
 	
 	my $out; 
 	
-	$out .= qq~</head>~; 
+	$out .= qq{</head>}; 
 	
 	if ($ARGV and $ARGV > 0 or scalar(@keys) > 0) 
 	{
 		
 		if (@_) 
 		{
-			return qq~@_\n~; 
+			return qq{@_\n}; 
 		}
 		else 
 		{
-			return qq~$out\n~; 
+			return qq{$out\n}; 
 		}
 		
 	}
 	else 
 	{
-		return qq~$out\n~; 	# this works but does not ask the user
+		return qq{$out\n}; 	# this works but does not ask the user
 	}
 } 
 # end end head 
@@ -545,24 +543,24 @@ sub begin_body
 	
 	my $out; 
 	
-	$out .= qq~<body>~; 
+	$out .= qq{<body>}; 
 	
 	if ($ARGV and $ARGV > 0 or scalar(@keys) > 0) 
 	{
 		
 		if (@_) 
 		{
-			return qq~@_\n~; 
+			return qq{@_\n}; 
 		}
 		else 
 		{
-			return qq~$out\n~; 
+			return qq{$out\n}; 
 		}
 		
 	}
 	else 
 	{
-		return qq~$out\n~; 	# this works but does not ask the user
+		return qq{$out\n}; 	# this works but does not ask the user
 	}
 } 
 # end begin body
@@ -584,7 +582,7 @@ sub body_accordion
 	
 	my $out; 
 	
-	$out .= qq~<!--begin Content--> 
+	$out .= qq{<!--begin Content--> 
 <div id="accordion617" class="accordion">
 	<h3>Who is it for</h3>
 	<div>For those who know/uderstand Perl/HTML/jQuery</div>
@@ -597,24 +595,24 @@ sub body_accordion
 </div>
 
 <!--end Content-->
-~; 
+}; 
 	
 	if ($ARGV and $ARGV > 0 or scalar(@keys) > 0) 
 	{
 		
 		if (@_) 
 		{
-			return qq~@_\n~; 
+			return qq{@_\n}; 
 		}
 		else 
 		{
-			return qq~\n<!--525--> \n$out\n~; 
+			return qq{\n<!--525--> \n$out\n}; 
 		}
 		
 	}
 	else 
 	{
-		return qq~\n$out\n~; 	#
+		return qq{\n$out\n}; 	#
 	}
 } 
 # end accordion
@@ -661,24 +659,24 @@ sub end_body
 	
 	my $out; 
 	
-	$out .= qq~\n</body>\n~; 
+	$out .= qq{\n</body>\n}; 
 	
 	if ($ARGV and $ARGV > 0 or scalar(@keys) > 0) 
 	{
 		
 		if (@_) 
 		{
-			return qq~@_\n~; 
+			return qq{@_\n}; 
 		}
 		else 
 		{
-			return qq~$out\n~; 
+			return qq{$out\n}; 
 		}
 		
 	}
 	else 
 	{
-		return qq~$out\n~; 	# this works but does not ask the user
+		return qq{$out\n}; 	# this works but does not ask the user
 	}
 } 
 # end end body
@@ -723,17 +721,17 @@ sub body_form
 	{
 		# get the params for the form 
 		my ($sel_key, $sel_name, $sel_default, $folder_or_file) = split(/\,/, $form_vars[3], 4); 
-		$select .= qq~<label for"$sel_name">$sel_default</label>
+		$select .= qq{<label for"$sel_name">$sel_default</label>
 <div class="form-group"><!--begin select-->
 <select name="$sel_name">
 	<option selected value="$sel_default">$sel_default</option>
-~;
+};
 		
 		#now open file/folder to fill "options" 
 		if ( -f $folder_or_file ) 
 		{
 			# open as file 
-			#$select .= qq~none~; 
+			#$select .= qq{none}; 
 		}
 		elsif (-d $folder_or_file)
 		{
@@ -751,7 +749,7 @@ sub body_form
 				next if $file =~ /^(\.|\.\.)/; 
 				# do not add hidden files to the options list
 				next if $file =~ /^\./; 
-				#$select .= '  ' x 8 . qq~<option value="$file">$file</option>\n~ if $file; 	# ' ' x 8 = 8 spaces 
+				#$select .= '  ' x 8 . qq{<option value="$file">$file</option>\n~ if $file; 	# ' ' x 8 = 8 spaces 
 				
 				# get the size of th file 
 				my $size = -s "$folder_or_file/$file"; 
@@ -759,34 +757,34 @@ sub body_form
 					$size /= 1024; 
 					$size /= 1024;
 					$size = sprintf "%.2f", $size; 
-				$select .= qq~\t<option value="$file">$file [$size mb]</option>\n~ if $file; 	# ' ' x 9 #= spaces
+				$select .= qq{\t<option value="$file">$file [$size mb]</option>\n~ if $file; 	# ' ' x 9 #= spaces
 			}
 		}
 
-$select .= qq~</select>
+$select .= qq{</select>
 </div><!--end select-->
-~; 
+}; 
 	}
 	else 
 	{
 		# no select
-		$select .= qq~~; 
+		$select .= qq{}; 
 	}
 	 
 	
-	$out .= qq~<form action="$form_vars[2]" method="$form_vars[1]">~;  
+	$out .= qq{<form action="$form_vars[2]" method="$form_vars[1]">};  
 	
 		# add hidden fields/values # from $form_vars[4] 
 		for (@hidden)
 		{
 			my ($name, $value) = split(/---/, $_, 2) if $_; 
-			$out .= qq~<input type="hidden" name="$name" value="$value"/>\n~ if $_; 
+			$out .= qq{<input type="hidden" name="$name" value="$value"/>\n~ if $_; 
 		}
 		# add select 
-		$out .= qq~$select~;  
-	$out .= qq~\n<button type="submit" class="btn btn-default">Submit</button>\n</form>\n\n~; 
+		$out .= qq{$select};  
+	$out .= qq{\n<button type="submit" class="btn btn-default">Submit</button>\n</form>\n\n}; 
 	
-	return qq~$out~; 
+	return qq{$out}; 
 	
 	
 }
@@ -836,10 +834,10 @@ sub defaults_end
 
 # HTML 
 my %HTML = (
-	-defaultjquery => qq~<script type="text/javascript" src="/jquery/jquery-1.11.1.min.js"></script>
+	-defaultjquery => qq{<script src="https://code.jquery.com/ui/1.11.4/jquery-ui.min.js"></script>
 <!--bootstrap/jQueryUI-->
-<script type="text/javascript" src="/jquery/bootstrap/js/bootstrap.min.js"></script>
-<script type="text/javascript" src="/jquery/ui/1.11.2.lightness/jquery-ui.min.js"></script>
+<script type="text/javascript" src="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.0/js/bootstrap.min.js"></script>
+<script type="text/javascript" src="https://code.jquery.com/ui/1.11.4/themes/ui-lightness/jquery-ui.css"></script>
 <!-- IE10 viewport hack for Surface/desktop Windows 8 bug -->
 <script type="text/javascript" src="/jquery/bootstrap/fixed-top/ie10-viewport-bug-workaround.js"></script>
 <script type="text/javascript">
@@ -881,33 +879,32 @@ my %HTML = (
 \$('accordion617').accordion();
 \$('#tabs').tabs(); 
 </script>
-~,
+},
 	 
 );
 
 sub html_bootstrap_css   
 {
-	return qq~<!-- Bootstrap/jqueryUI -->
-<link href="/jquery/bootstrap/css/bootstrap.min.css" rel="stylesheet" type="text/css">
-<link href="/jquery/bootstrap/fixed-top/navbar-fixed-top.css" rel="stylesheet">
-~;  
+	return qq{<!-- Bootstrap/jqueryUI -->
+<link href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.0/css/bootstrap.min.css" rel="stylesheet" type="text/css">
+<link href="https://secure.bislinks.com/jquery/bootstrap/fixed-top/navbar-fixed-top.css" rel="stylesheet">
+};  
 }
 
 sub html_jqueryui_css 
 {
-	return qq~<link href="/jquery/ui/themes/smoothness/jquery-ui.min.css" rel="stylesheet">
-<link href="/jquery/ui/themes/smoothness/theme.css" rel="stylesheet"> 
-~; 
+	# jquery ui theme 1.12.0
+	return qq{<link href="https://code.jquery.com/ui/1.12.0/themes/smoothness/jquery-ui.css" rel="stylesheet">}; 
 }
 
 sub html_shim_respond 
 {
-	return qq~<!-- HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries -->
+	return qq{<!-- HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries -->
 <!--[if lt IE 9]>
 <script src="https://oss.maxcdn.com/html5shiv/3.7.2/html5shiv.min.js"></script>
 <script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
 <![endif]-->
-~;
+};
 
 }
 
@@ -924,33 +921,32 @@ sub html_navbar
 		@_,		
 	);
 	
-	return qq~<script type="text/javascript" src="/jquery/top-nav-bar.js"></script>
+	return qq{<script src="/jquery/top-nav-bar.js"></script>
 <!--top nav bar begin-->
-<script type="text/javascript">
+<script>
 //<-- 
-//fixed_top_navbar('$i{-nbpage1}', '', '$i{-nbmenu1}', '', '');
 fixed_top_navbar('$_[0]', '', '$_[1]', '', '');
 //-->
 </script>
 <!-- top nav bar end--> 
-~; 
+}; 
 
 }
 
 
 sub html_bootstrap_js  
 {
-	return qq~<!-- Bootstrap/jqueryUI -->
-<link href="/jquery/bootstrap/css/bootstrap.min.css" rel="stylesheet" type="text/css">
-<link href="/jquery/bootstrap/fixed-top/navbar-fixed-top.css" rel="stylesheet">
-<link href="/jquery/ui/themes/smoothness/jquery-ui.min.css" rel="stylesheet">
-<link href="/jquery/ui/themes/smoothness/theme.css" rel="stylesheet">
+	# jquery:3.3.0 ui:1/12/1
+	return qq{<!-- Bootstrap/jqueryUI -->
+<link href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.0/css/bootstrap.min.css" rel="stylesheet" type="text/css">
+<link href="https://secure.bislinks.com/jquery/bootstrap/fixed-top/navbar-fixed-top.css" rel="stylesheet">
+<link href="https://code.jquery.com/ui/1.12.1/themes/smoothness/jquery-ui.css" rel="stylesheet">
 <!-- HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries -->
 <!--[if lt IE 9]>
 <script src="https://oss.maxcdn.com/html5shiv/3.7.2/html5shiv.min.js"></script>
 <script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
 <![endif]-->
-~; 
+}; 
 
 }
 
@@ -966,21 +962,21 @@ sub html_jquery
 
 sub html_humanejs_css
 {
-	return qq~<link rel='stylesheet' href='/jquery/humane-js/themes/bigbox.css'>
-      <link rel='stylesheet' href='/jquery/humane-js/themes/boldlight.css'>
-      <link rel='stylesheet' href='/jquery/humane-js/themes/jackedup.css'>
-      <link rel='stylesheet' href='/jquery/humane-js/themes/libnotify.css'>
-      <link rel='stylesheet' href='/jquery/humane-js/themes/original.css'>
-<link rel='stylesheet' href='/jquery/humane-js/themes/flatty.css'>
+	return qq{<link rel='stylesheet' href='https://cdnjs.cloudflare.com/ajax/libs/humane-js/3.2.2/themes/bigbox.css'>
+      <link rel='stylesheet' href='https://cdnjs.cloudflare.com/ajax/libs/humane-js/3.2.2/themes/boldlight.css'>
+      <link rel='stylesheet' href='https://cdnjs.cloudflare.com/ajax/libs/humane-js/3.2.2/themes/jackedup.css'>
+      <link rel='stylesheet' href='https://cdnjs.cloudflare.com/ajax/libs/humane-js/3.2.2/themes/libnotify.css'>
+      <link rel='stylesheet' href='/https://cdnjs.cloudflare.com/ajax/libs/humane-js/3.2.2/themes/original.css'>
+<link rel='stylesheet' href='https://cdnjs.cloudflare.com/ajax/libs/humane-js/3.2.2/themes/flatty.min.css'>
 <link href='http://fonts.googleapis.com/css?family=Ubuntu&v2' rel='stylesheet' type='text/css'>
 <link href='http://fonts.googleapis.com/css?family=Ubuntu+Mono' rel='stylesheet' type='text/css'>
 <link href='http://fonts.googleapis.com/css?family=Cabin+Sketch:700&v2' rel='stylesheet' type='text/css'>
-~; 
+}; 
 }
 
 sub html_bootstrap_bluimp 
 {
-	return qq~<!-- The Bootstrap Image Gallery lightbox, should be a child element of the document body -->
+	return qq{<!-- The Bootstrap Image Gallery lightbox, should be a child element of the document body -->
 		<div id="blueimp-gallery" class="blueimp-gallery blueimp-gallery-controls" data-use-bootstrap-modal="false">
 	    <!-- The container for the modal slides -->
 	    <div class="slides"></div>
@@ -1014,7 +1010,7 @@ sub html_bootstrap_bluimp
 	        </div>
 	    </div>
 	</div>
-	~;
+	};
 }
 # end sub html_bootstrap_bluimp 
 
@@ -1033,9 +1029,9 @@ sub head
 		-title 		=> "Page Title", 
 		-cssLinks => "", 
 		-cssCode => "", 
-		-mobilemeta => qq~<meta name="HandheldFriendly" content="true">
-<meta name="viewport" content="width=device-width, initial-scale=1.0">~, 
-		-charsetmeta => qq~<meta charset="utf-8">~, 
+		-mobilemeta => qq{<meta name="HandheldFriendly" content="true">
+<meta name="viewport" content="width=device-width, initial-scale=1.0">}, 
+		-charsetmeta => qq{<meta charset="utf-8">}, 
 		-usermeta => "",
 		@_,
 		
@@ -1043,7 +1039,7 @@ sub head
 	
 	for (keys %in) 
 	{
-		#$out .= qq~$in{$_}\n~;  # disordered 
+		#$out .= qq{$in{$_}\n};  # disordered 
 		
 	}
 
@@ -1058,7 +1054,7 @@ if ($in{-cssLinks} )
 		{
 			if ($_ =~ /\.css$/) 
 			{
-				$css .= qq~<link type="text/css" rel="stylesheet" href="$_">\n~ ; 
+				$css .= qq{<link type="text/css" rel="stylesheet" href="$_">\n~ ; 
 			}
 			else 
 			{
@@ -1069,11 +1065,11 @@ if ($in{-cssLinks} )
 }
 else 
 {
-	$css = qq~~; 
+	$css = qq{}; 
 }
 
 
-	return qq~$in{-type}<!DOCTYPE html>
+	return qq{$in{-type}<!DOCTYPE html>
 <html>
 <head>
 <title>$in{-title}</title> 
@@ -1089,11 +1085,13 @@ $css
 $in{-cssCode}
 </style>
 </head>
-~; 	# thats orderly 
+}; 	# thats orderly 
 
 }
 # end head 
 
+
+
 sub body 
 {
 	my $self = shift; 
@@ -1103,24 +1101,24 @@ sub body
 	my %in; 
 	
 	%in = (
-		-h1		=> qq~$ENV{SERVER_NAME}~,
-		-onload => qq~setTitle();~,  
-		-nbhead 	=> qq~~,
-		-nbpage => qq~~, 
-		-nbmenu => qq~~, 
-		-defaultjquery => qq~$HTML{-defaultjquery}~, 
-		-humanejs => qq~<script type="text/javascript" src="/jquery/js/humane-js/humane.min.js">~, 
-		-userjquery => qq~~, 
+		-h1		=> qq{$ENV{SERVER_NAME}},
+		-onload => qq{setTitle();},  
+		-nbhead 	=> qq{},
+		-nbpage => qq{}, 
+		-nbmenu => qq{}, 
+		-defaultjquery => qq{$HTML{-defaultjquery}}, 
+		-humanejs => qq{<script type="text/javascript" src="https://cdnjs.cloudflare.com/ajax/libs/humane-js/3.2.2/humane.min.js">},
+		-userjquery => qq{}, 
 		-navbar => html_navbar( $in{-nbmenu}, $in{-nbpage}, "Obselete Thu Mar 26 10:03:47 2015") , 
-		-content => qq~<div class="content">Content</div>~, 
-		-footer => qq~All rights reserved &copy; $ENV{SERVER_NAME}~, 	
+		-content => qq{<div class="content">Content</div>}, 
+		-footer => qq{All rights reserved &copy; $ENV{SERVER_NAME}}, 	
 		-bootstrapbluimp => html_bootstrap_bluimp, 	
 		@_, 		
 	); 
 	
-	return qq~<body onload="$in{-onload}">
+	return qq{<body onload="$in{-onload}">
 <div id="main" class="container">
-		<script type="text/javascript" src="/jquery/utils/top-nav-bar.js"></script>
+		<script type="text/javascript" src="https://secure.bislinks.com/jquery/utils/top-nav-bar.js"></script>
 <!--top nav bar begin-->
 <script type="text/javascript">
 //<-- 
@@ -1148,7 +1146,7 @@ $in{-userjquery}
 	
 </html>
 	
-~; 
+}; 
 
 }
 # end body 
@@ -1168,7 +1166,7 @@ sub create_accordion
 	} 
 	else 
 	{
-		$out .= qq~#55 Unable to open file $file~; 
+		$out .= qq{#55 Unable to open file $file}; 
 	
 	}
 	
@@ -1197,36 +1195,36 @@ sub open_file
 	
 	if (open(FILE, "$file") )
 	{
-		#open(FILE, "$file") or $out .= qq~77 $!~; 
+		#open(FILE, "$file") or $out .= qq{77 $!}; 
 		
 		@data = <FILE>; 
 		
-		$out .= qq~\n<!--begin file output-->\n<div class="file_output">\n~; 
+		$out .= qq{\n<!--begin file output-->\n<div class="file_output">\n}; 
 		
 		# Step 1 
 		# set the header as per format  
 		if ($output_format eq 'table') 
 		{ 
-			$out .= qq~<table class="table table-striped table-bordered table-hover table-condensed table-responsive">
+			$out .= qq{<table class="table table-striped table-bordered table-hover table-condensed table-responsive">
 				<thead>
 					<tr><th colspan="2">$output_header</th></tr>
 				</thead>
 				<tbody>
-			~; 
+			}; 
 		}
 		elsif ($output_format eq 'accordion')
 		{
-			$out .= qq~<h2>$output_header</h2>\n<div id="accordion2" class="accordion"><!--118-->\n~;
+			$out .= qq{<h2>$output_header</h2>\n<div id="accordion2" class="accordion"><!--118-->\n};
 		} 
 		elsif ($output_format eq 'menu') 
 		{
-			$out .= qq~<ul class="menu" id="menu">\n<li><a href="/">$output_header</a>\n<ul>~;
+			$out .= qq{<ul class="menu" id="menu">\n<li><a href="/">$output_header</a>\n<ul>};
 		}
 		elsif ($output_format eq 'tabs')
 		{
 			# special case for tabs since the data needs to be formatted a little differently 
 			
-			$out .= qq~<h2>$output_header</h2>\n<div id="tabs">\n<ul>\n~;
+			$out .= qq{<h2>$output_header</h2>\n<div id="tabs">\n<ul>\n};
 			
 			my $sl = '0'; 
 			
@@ -1263,18 +1261,18 @@ sub open_file
 						$h1 =~ s!^==!!g;
 					}
 				
-					$out .= qq~\t<li><a href="#tabs-$sl">$h1</a></li>\n~; 
+					$out .= qq{\t<li><a href="#tabs-$sl">$h1</a></li>\n}; 
 				}
-			$out .= qq~</ul>\n~; 
+			$out .= qq{</ul>\n}; 
 		}
 		elsif ($output_format eq 'dialog')
 		{
-			$out .= qq~<h2>Dialog: <a href="#opener" id="opener" title="Opens the Dialog">$output_header</a></h2>
-<div id="dialog">\n~; 
+			$out .= qq{<h2>Dialog: <a href="#opener" id="opener" title="Opens the Dialog">$output_header</a></h2>
+<div id="dialog">\n}; 
 		}
 		else 
 		{
-			$out .= qq~\n<h2>$output_header</h2>\n~; 
+			$out .= qq{\n<h2>$output_header</h2>\n}; 
 		}
 		# End Step 1
 		
@@ -1328,7 +1326,7 @@ sub open_file
 					$div =~ s!^#!!g;
 					$h1 =~ s!^#!!g;
 				}
-				$out .= qq~\t<tr><td>$h1</td><td>$div</td></tr>\n~; 
+				$out .= qq{\t<tr><td>$h1</td><td>$div</td></tr>\n}; 
 			}
 			elsif ($output_format eq 'accordion')
 			{
@@ -1347,7 +1345,7 @@ sub open_file
 					$h1 =~ s!^--!!g;
 				} 
 				
-				$out .= qq~\t<h3>$h1</h3>\n\t<div>$div</div>\n~ if $line; 
+				$out .= qq{\t<h3>$h1</h3>\n\t<div>$div</div>\n~ if $line; 
 			} 
 			elsif ($output_format eq 'menu') 
 			{
@@ -1373,7 +1371,7 @@ sub open_file
 					$div =~ s!^http!!g;
 					$h1 =~ s!^http!!g;
 				}
-				$out .= qq~\t<li id="li-$serial"><a id="a-$serial" href="$div" title="$h1">$h1</a></li>\n~;
+				$out .= qq{\t<li id="li-$serial"><a id="a-$serial" href="$div" title="$h1">$h1</a></li>\n};
 			}
 			elsif ($output_format eq 'tabs') 
 			{
@@ -1392,7 +1390,7 @@ sub open_file
 					$h1 =~ s!^==!!g;
 				}
 				
-				$out .= qq~\t<div id="tabs-$serial"><p>$div</p></div>\n~; 
+				$out .= qq{\t<div id="tabs-$serial"><p>$div</p></div>\n}; 
 			}
 			elsif ($output_format eq 'dialog')
 			{
@@ -1402,46 +1400,46 @@ sub open_file
 				$div =~ s!^(==|\#|--)!!g;
 				$h1 =~ s!^(==|\#|--)!!g;
 					
-				$out .= qq~<p>$h1</p>\n<p>$div</p>\n~; 
+				$out .= qq{<p>$h1</p>\n<p>$div</p>\n}; 
 			}
 			else 
 			{
-				$out .= qq~$h1 $div~; 	# or $line
+				$out .= qq{$h1 $div}; 	# or $line
 			}
 		} 
 		
 		# add an extra item at the end of file output
-		#$out .= qq~\t<h3>Powered by Business Impact Solutions</h3>\n\t<div>bislinks.com, bizImpactSolutions.com - Business Impact Solutions</div>\n~; 
+		#$out .= qq{\t<h3>Powered by Business Impact Solutions</h3>\n\t<div>bislinks.com, bizImpactSolutions.com - Business Impact Solutions</div>\n}; 
 		
 		# Step 3 
 		# set the output ending as per format  
 		if ($output_format eq 'table') 
 		{ 
-			$out .= qq~\n</tbody>\n</table>\n\n~; 
+			$out .= qq{\n</tbody>\n</table>\n\n}; 
 		}
 		elsif ($output_format eq 'accordion')
 		{
-			$out .= qq~\n<!--end accordion--></div>\n\n~;
+			$out .= qq{\n<!--end accordion--></div>\n\n};
 		} 
 		elsif ($output_format eq 'menu') 
 		{
-			$out .= qq~</ul></ul>~;
+			$out .= qq{</ul></ul>};
 		}
 		elsif ($output_format eq 'tabs')
 		{
-			$out .= qq~</div><!--end tabs-->\n~; 
+			$out .= qq{</div><!--end tabs-->\n}; 
 		}
 		elsif ($output_format eq 'dialog') 
 		{
-			$out .= qq~</div><!--end dialog-->\n~; 
+			$out .= qq{</div><!--end dialog-->\n}; 
 		}
 		else 
 		{
-			$out .= qq~\n\n~; 
+			$out .= qq{\n\n}; 
 		}
 		
 		# end file output wrapper
-		$out .= qq~</div><!--end file output-->\n~; 
+		$out .= qq{</div><!--end file output-->\n}; 
 		
 		close FILE; 
 		
@@ -1453,7 +1451,7 @@ sub open_file
 		
 		@data = <DATA>; 
 	
-		$out .= qq~\n<!--begin accord 112-->\n<div id="accordion1460" class="accordion">\n~; 
+		$out .= qq{\n<!--begin accord 112-->\n<div id="accordion1460" class="accordion">\n}; 
 		foreach my $line (@data) 
 		{ 
 			chomp $line; 
@@ -1462,11 +1460,11 @@ sub open_file
 			
 			($h1, $div) = split(/\t+/, $line, 2) if $line; 
 			
-			$out .= qq~\t<h3>$h1</h3>\n\t<div>$div</div>\n~ if $line; 
+			$out .= qq{\t<h3>$h1</h3>\n\t<div>$div</div>\n~ if $line; 
 		} 
-		$out .= qq~\t<h3>Powered by</h3>\n\t<div>Package HTML5</div>\n~; 
+		$out .= qq{\t<h3>Powered by</h3>\n\t<div>Package HTML5</div>\n}; 
 		
-		$out .= qq~</div>\n<!--end accord-->\n~; 
+		$out .= qq{</div>\n<!--end accord-->\n}; 
 		
 		return $out; 
 	}
@@ -1590,7 +1588,7 @@ sub write_file
 			my @f = <F>;
 			
 			# save original file content to backup file
-			open(BAK, ">$in{file}.bak.txt") or $in{error} .= "#1570 Unable to create backup file '$in{file}.bak.txt' '$!' <br/>";
+			open(BAK, ">$in{file},bak.txt") or $in{error} .= "#1570 Unable to create backup file '$in{file},bak.txt' '$!' <br/>";
 			for (@f)
 			{
 				print BAK qq{$_};	
@@ -1630,7 +1628,7 @@ sub write_file
 			close FILE;
 			
 			
-			if (-e -f "$in{file}.bak.txt" and -e -f "$in{file}")
+			if (-e -f "$in{file},bak.txt" and -e -f "$in{file}")
 			{	
 				return "<div class='success'>Saved</div> <div class='error'>$in{error}</div>";
 			}
@@ -1668,36 +1666,72 @@ __END__
 
 =head1 NAME
 
-A1z::HTML5::Template - turns baubles into trinkets
+A1z::HTML5::Template - Fast/easy HTML5 apps/pages in Perl
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
-Quick summary of what the module does.
-
-Perhaps a little code snippet.
-
     use A1z::HTML5::Template;
-
     my $foo = A1z::HTML5::Template->new();
-    ...
+
+    use lib '/home/user/path/to/app';
+
+	# for features like 'say'
+	use 5.10.0;
+
+	my $h = A1z::HTML5::Template->new(); 
+
+	say $h->header('utf8');  
+	say $h->start_html(); 
+	say $h->head_title("My New App"); 
+	say $h->head_meta(); 
+	say $h->head_js_css(); 
+	say $h->head_js_css('/url/to/app/Template.css'); 
+	say $h->end_head(); 
+	say $h->begin_body();
+
+	say qq{<h1>My New App/Website</h1>};
+
+	say qq{<main class="container">}; 
+
+	# output file content as menu
+	say $h->body_accordion( $h->open_file("/home/user/path/to/app/open_file_example.txt", 'menu', 'Menu') ); 
+
+	# as a HTML5 table 
+	say $h->body_accordion( $h->open_file("$sys{cgibase}/open_file_example.txt", 'table', 'Table Header') );
+		
+	# math works 
+	say $h->body_article( header => "Simple Mathematics", content => $h->math1("2", "4") );
+
+	# math works 
+	say $h->body_article( header => "Times Table", content => $h->timestable("2") );
+
+	# Both body_accordion and body_article are used synonymously and do the same thing but with little variations.
+
+	say qq{</main>};
+
+	say $h->body_js_css(); 
+	say $h->end_body();
+	say $h->end_html(); 
 
 =head1 NAME
 
-A1z::HTML5::Template
+	A1z::HTML5::Template is a perl implementation of customizable HTML5 tags.
+
+=head1 Installation
+
+	cpan install A1z::HTML5::Template 
+	or
+	cpanm A1z::HTML5::Template
 
 =head1 VERSION
 
-Version 0.07
+	Version 0.08
 
-=head1 EXPORT
-
-A list of functions that can be exported.
-
-=head1 SUBROUTINES/METHODS
+=head1 METHODS
 
 header start_html head_title head_meta head_js_css end_head begin_body body_js_css body_topnavbar 
 body_accordion end_body end_html 
@@ -1705,16 +1739,15 @@ body_accordion end_body end_html
 =head2 new
 
    use A1z::HTML5::Template;
-   my $foo = A1z::HTML5::Template->new();
+   my $h = A1z::HTML5::Template->new();
 
 =head2 math1
 
-Usage
-
-$foo->math1(num1, num2);
+	$h->math1(num1, num2);
 
 =head1 Times Table
-	usage $foo->timestable("Number");
+
+	$h->timestable("Number");
 
 =head1 Usage
 
